@@ -321,6 +321,7 @@ get_load (LoadGraph *graph)
     // that value has no meaning, we just want all the
     // graphs to be aligned, so the CPU graph needs to start
     // immediately
+    bool drawStacked = graph->type == LOAD_GRAPH_CPU && ProcmanApp::get()->config.draw_stacked;
 
     for (i = 0; i < graph->n; i++) {
         float load;
@@ -331,9 +332,12 @@ get_load (LoadGraph *graph)
         used  = NOW[i][CPU_USED]  - LAST[i][CPU_USED];
 
         load = used / MAX(total, 1.0f);
-        graph->data[0][i] = load / graph->n;
-        if (i > 0) {
-            graph->data[0][i] += graph->data[0][i-1];
+        graph->data[0][i] = load;
+        if (drawStacked) {
+            graph->data[0][i] /= graph->n;
+            if (i > 0) {
+                graph->data[0][i] += graph->data[0][i-1];
+            }
         }
 
         /* Update label */
