@@ -40,6 +40,7 @@
 #include "settings-keys.h"
 #include "procman_gnomesu.h"
 #include "procman_gksu.h"
+#include "procman_pkexec.h"
 #include "cgroups.h"
 
 static GtkWidget *renice_dialog = NULL;
@@ -55,28 +56,28 @@ kill_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
     gtk_widget_destroy (GTK_WIDGET (dialog));
 
     if (id == GTK_RESPONSE_OK)
-        kill_process (kargs->procdata, kargs->signal);
+        kill_process (kargs->app, kargs->signal);
 
     g_free (kargs);
 }
 
 void
-procdialog_create_kill_dialog (ProcData *procdata, int signal)
+procdialog_create_kill_dialog (ProcmanApp *app, int signal)
 {
     GtkWidget *kill_alert_dialog;
     gchar *primary, *secondary, *button_text;
     struct KillArgs *kargs;
 
     kargs = g_new(KillArgs, 1);
-    kargs->procdata = procdata;
+    kargs->app = app;
     kargs->signal = signal;
 
 
     if (signal == SIGKILL) {
         /*xgettext: primary alert message*/
-        primary = g_strdup_printf (_("Kill the selected process »%s« (PID: %u)?"),
-                                   procdata->selected_process->name,
-                                   procdata->selected_process->pid);
+        primary = g_strdup_printf (_("Kill the selected process “%s” (PID: %u)?"),
+                                   app->selected_process->name,
+                                   app->selected_process->pid);
         /*xgettext: secondary alert message*/
         secondary = _("Killing a process may destroy data, break the "
                       "session or introduce a security risk. "
@@ -85,9 +86,9 @@ procdialog_create_kill_dialog (ProcData *procdata, int signal)
     }
     else {
         /*xgettext: primary alert message*/
-        primary = g_strdup_printf (_("End the selected process »%s« (PID: %u)?"),
-                                   procdata->selected_process->name,
-                                   procdata->selected_process->pid);
+        primary = g_strdup_printf (_("End the selected process “%s” (PID: %u)?"),
+                                   app->selected_process->name,
+                                   app->selected_process->pid);
         /*xgettext: secondary alert message*/
         secondary = _("Ending a process may destroy data, break the "
                       "session or introduce a security risk. "
@@ -95,7 +96,7 @@ procdialog_create_kill_dialog (ProcData *procdata, int signal)
         button_text = _("_End Process");
     }
 
-    kill_alert_dialog = gtk_message_dialog_new (GTK_WINDOW (procdata->app),
+    kill_alert_dialog = gtk_message_dialog_new (GTK_WINDOW (app->main_window),
                                                 static_cast<GtkDialogFlags>(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
                                                 GTK_MESSAGE_WARNING,
                                                 GTK_BUTTONS_NONE,
@@ -127,7 +128,7 @@ renice_scale_changed (GtkAdjustment *adj, gpointer data)
     GtkWidget *label = GTK_WIDGET (data);
 
     new_nice_value = int(gtk_adjustment_get_value (adj));
-    gchar* text = g_strdup_printf(_("(%s Priority)"), procman::get_nice_level (new_nice_value));
+    gchar* text = g_strdup(procman::get_nice_level_with_priority (new_nice_value));
     gtk_label_set_text (GTK_LABEL (label), text);
     g_free(text);
 
@@ -136,12 +137,11 @@ renice_scale_changed (GtkAdjustment *adj, gpointer data)
 static void
 renice_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 {
-    ProcData *procdata = static_cast<ProcData*>(data);
-
+    ProcmanApp *app = static_cast<ProcmanApp *>(data);
     if (id == 100) {
         if (new_nice_value == -100)
             return;
-        renice(procdata, new_nice_value);
+        renice(app, new_nice_value);
     }
 
     gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -149,9 +149,9 @@ renice_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 }
 
 void
-procdialog_create_renice_dialog (ProcData *procdata)
+procdialog_create_renice_dialog (ProcmanApp *app)
 {
-    ProcInfo *info = procdata->selected_process;
+    ProcInfo *info = app->selected_process;
     GtkWidget *label;
     GtkWidget *priority_label;
     GtkAdjustment *renice_adj;
@@ -172,7 +172,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
 
     renice_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "renice_dialog"));
 
-    dialog_title = g_strdup_printf (_("Change Priority of Process »%s« (PID: %u)"),
+    dialog_title = g_strdup_printf (_("Change Priority of Process “%s” (PID: %u)"),
                                     info->name, info->pid);
 
     gtk_window_set_title (GTK_WINDOW(renice_dialog), dialog_title);
@@ -188,7 +188,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
     new_nice_value = 0;
     
     priority_label =  GTK_WIDGET (gtk_builder_get_object (builder, "priority_label"));
-    gtk_label_set_label (GTK_LABEL(priority_label), procman::get_nice_level (info->nice));
+    gtk_label_set_label (GTK_LABEL(priority_label), procman::get_nice_level_with_priority (info->nice));
 
     text = g_strconcat("<small><i><b>", _("Note:"), "</b> ",
                        _("The priority of a process is given by its nice value. A lower nice value corresponds to a higher priority."),
@@ -199,7 +199,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
     g_free (text);
 
     g_signal_connect (G_OBJECT (renice_dialog), "response",
-                      G_CALLBACK (renice_dialog_button_pressed), procdata);
+                      G_CALLBACK (renice_dialog_button_pressed), app);
     g_signal_connect (G_OBJECT (renice_adj), "value_changed",
                       G_CALLBACK (renice_scale_changed), priority_label);
 
@@ -234,8 +234,8 @@ prefs_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 static void
 show_kill_dialog_toggled (GtkToggleButton *button, gpointer data)
 {
-    ProcData *procdata = static_cast<ProcData*>(data);
-    GSettings *settings = procdata->settings;
+    ProcmanApp *app = static_cast<ProcmanApp *>(data);
+    GSettings *settings = app->settings;
 
     gboolean toggled;
 
@@ -249,20 +249,31 @@ show_kill_dialog_toggled (GtkToggleButton *button, gpointer data)
 static void
 solaris_mode_toggled(GtkToggleButton *button, gpointer data)
 {
-    ProcData *procdata = static_cast<ProcData*>(data);
-    GSettings *settings = procdata->settings;
+    ProcmanApp *app = static_cast<ProcmanApp *>(data);
+    GSettings *settings = app->settings;
 
     gboolean toggled;
     toggled = gtk_toggle_button_get_active(button);
     g_settings_set_boolean(settings, procman::settings::solaris_mode.c_str(), toggled);
 }
 
+static void
+draw_stacked_toggled(GtkToggleButton *button, gpointer data)
+{
+    ProcmanApp *app = static_cast<ProcmanApp *>(data);
+    GSettings *settings = app->settings;
+
+    gboolean toggled;
+    toggled = gtk_toggle_button_get_active(button);
+    g_settings_set_boolean(settings, procman::settings::draw_stacked.c_str(), toggled);
+}
+
 
 static void
 network_in_bits_toggled(GtkToggleButton *button, gpointer data)
 {
-    ProcData *procdata = static_cast<ProcData*>(data);
-    GSettings *settings = procdata->settings;
+    ProcmanApp *app = static_cast<ProcmanApp *>(data);
+    GSettings *settings = app->settings;
 
     gboolean toggled;
     toggled = gtk_toggle_button_get_active(button);
@@ -274,8 +285,8 @@ network_in_bits_toggled(GtkToggleButton *button, gpointer data)
 static void
 smooth_refresh_toggled(GtkToggleButton *button, gpointer data)
 {
-    ProcData *procdata = static_cast<ProcData*>(data);
-    GSettings *settings = procdata->settings;
+    ProcmanApp *app = static_cast<ProcmanApp *>(data);
+    GSettings *settings = app->settings;
 
     gboolean toggled;
 
@@ -289,8 +300,8 @@ smooth_refresh_toggled(GtkToggleButton *button, gpointer data)
 static void
 show_all_fs_toggled (GtkToggleButton *button, gpointer data)
 {
-    ProcData *procdata = static_cast<ProcData*>(data);
-    GSettings *settings = procdata->settings;
+    ProcmanApp *app = static_cast<ProcmanApp *>(data);
+    GSettings *settings = app->settings;
 
     gboolean toggled;
 
@@ -321,7 +332,7 @@ private:
     {
         int new_value = int(1000 * gtk_spin_button_get_value(spin));
 
-        g_settings_set_int(ProcData::get_instance()->settings,
+        g_settings_set_int(ProcmanApp::get()->settings,
                            this->key.c_str(), new_value);
 
         procman_debug("set %s to %d", this->key.c_str(), new_value);
@@ -341,7 +352,7 @@ field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
     GtkTreeIter iter;
     GtkTreeViewColumn *column;
     gboolean toggled;
-    GSettings *settings = g_settings_get_child (ProcData::get_instance()->settings, "proctree");
+    GSettings *settings = g_settings_get_child (ProcmanApp::get()->settings, "proctree");
     gchar *key;
     int id;
 
@@ -442,7 +453,7 @@ create_field_page(GtkBuilder* builder, GtkWidget *tree, const gchar *widgetname)
 }
 
 void
-procdialog_create_preferences_dialog (ProcData *procdata)
+procdialog_create_preferences_dialog (ProcmanApp *app)
 {
     typedef SpinButtonUpdater SBU;
 
@@ -472,7 +483,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     spin_button = GTK_WIDGET (gtk_builder_get_object (builder, "processes_interval_spinner"));
 
-    update = (gfloat) procdata->config.update_interval;
+    update = (gfloat) app->config.update_interval;
     adjustment = (GtkAdjustment *) gtk_adjustment_new(update / 1000.0,
                                                       MIN_UPDATE_INTERVAL / 1000,
                                                       MAX_UPDATE_INTERVAL / 1000,
@@ -486,27 +497,34 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     smooth_button = GTK_WIDGET (gtk_builder_get_object (builder, "smooth_button"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(smooth_button),
-                                 g_settings_get_boolean(procdata->settings,
+                                 g_settings_get_boolean(app->settings,
                                                         SmoothRefresh::KEY.c_str()));
     g_signal_connect(G_OBJECT(smooth_button), "toggled",
-                     G_CALLBACK(smooth_refresh_toggled), procdata);
+                     G_CALLBACK(smooth_refresh_toggled), app);
 
     check_button = GTK_WIDGET (gtk_builder_get_object (builder, "check_button"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button),
-                                  procdata->config.show_kill_warning);
+                                  app->config.show_kill_warning);
     g_signal_connect (G_OBJECT (check_button), "toggled",
-                      G_CALLBACK (show_kill_dialog_toggled), procdata);
+                      G_CALLBACK (show_kill_dialog_toggled), app);
 
     GtkWidget *solaris_button = GTK_WIDGET (gtk_builder_get_object (builder, "solaris_button"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(solaris_button),
-                                 g_settings_get_boolean(procdata->settings,
+                                 g_settings_get_boolean(app->settings,
                                                         procman::settings::solaris_mode.c_str()));
     g_signal_connect(G_OBJECT(solaris_button), "toggled",
-                     G_CALLBACK(solaris_mode_toggled), procdata);
+                     G_CALLBACK(solaris_mode_toggled), app);
 
-    create_field_page (builder, procdata->tree, "processes_columns_treeview");
+    GtkWidget *draw_stacked_button = GTK_WIDGET (gtk_builder_get_object (builder, "draw_stacked_button"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(draw_stacked_button),
+                                 g_settings_get_boolean(app->settings,
+                                                        procman::settings::draw_stacked.c_str()));
+    g_signal_connect(G_OBJECT(draw_stacked_button), "toggled",
+                     G_CALLBACK(draw_stacked_toggled), app);
 
-    update = (gfloat) procdata->config.graph_update_interval;
+    create_field_page (builder, app->tree, "processes_columns_treeview");
+
+    update = (gfloat) app->config.graph_update_interval;
     adjustment = (GtkAdjustment *) gtk_adjustment_new(update / 1000.0, 0.25,
                                                       100.0, 0.25, 1.0, 0);
     spin_button = GTK_WIDGET (gtk_builder_get_object (builder, "resources_interval_spinner"));
@@ -518,12 +536,12 @@ procdialog_create_preferences_dialog (ProcData *procdata)
     GtkWidget *bits_button = GTK_WIDGET (gtk_builder_get_object (builder, "bits_button"));
 
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bits_button),
-                                 g_settings_get_boolean(procdata->settings,
+                                 g_settings_get_boolean(app->settings,
                                                         procman::settings::network_in_bits.c_str()));
     g_signal_connect(G_OBJECT(bits_button), "toggled",
-                     G_CALLBACK(network_in_bits_toggled), procdata);
+                     G_CALLBACK(network_in_bits_toggled), app);
 
-    update = (gfloat) procdata->config.disks_update_interval;
+    update = (gfloat) app->config.disks_update_interval;
     adjustment = (GtkAdjustment *) gtk_adjustment_new (update / 1000.0, 1.0,
                                                        100.0, 1.0, 1.0, 0);
     spin_button = GTK_WIDGET (gtk_builder_get_object (builder, "devices_interval_spinner"));
@@ -535,18 +553,17 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     check_button = GTK_WIDGET (gtk_builder_get_object (builder, "all_devices_check"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button),
-                                  procdata->config.show_all_fs);
+                                  app->config.show_all_fs);
     g_signal_connect (G_OBJECT (check_button), "toggled",
-                      G_CALLBACK (show_all_fs_toggled), procdata);
+                      G_CALLBACK (show_all_fs_toggled), app);
 
-    create_field_page (builder, procdata->disk_list, "devices_columns_treeview");
+    create_field_page (builder, app->disk_list, "devices_columns_treeview");
 
     gtk_widget_show_all (prefs_dialog);
     g_signal_connect (G_OBJECT (prefs_dialog), "response",
-                      G_CALLBACK (prefs_dialog_button_pressed), procdata);
+                      G_CALLBACK (prefs_dialog_button_pressed), app);
 
-    switch (procdata->config.current_tab) {
-        case PROCMAN_TAB_SYSINFO:
+    switch (app->config.current_tab) {
         case PROCMAN_TAB_PROCESSES:
             gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 0);
             break;
@@ -588,7 +605,7 @@ procman_action_to_command(ProcmanActionType type,
  */
 gboolean
 procdialog_create_root_password_dialog(ProcmanActionType type,
-                                       ProcData *procdata,
+                                       ProcmanApp *app,
                                        gint pid,
                                        gint extra_value)
 {
@@ -599,7 +616,9 @@ procdialog_create_root_password_dialog(ProcmanActionType type,
 
     procman_debug("Trying to run '%s' as root", command);
 
-    if (procman_has_gksu())
+    if (procman_has_pkexec())
+        ret = procman_pkexec_create_root_password_dialog(command);
+    else if (procman_has_gksu())
         ret = procman_gksu_create_root_password_dialog(command);
     else if (procman_has_gnomesu())
         ret = procman_gnomesu_create_root_password_dialog(command);
